@@ -38,112 +38,112 @@ class Job extends JTable
 {
 	/**
 	 * int(11) Primary key
-	 *
+	 * 
 	 * @var integer
 	 */
 	var $id         		= NULL;
 
 	/**
 	 * int(11)
-	 *
+	 * 
 	 * @var integer
 	 */
 	var $cid       			= NULL;
 
 	/**
 	 * int(11)
-	 *
+	 * 
 	 * @var integer
 	 */
 	var $employerid      	= NULL;
 
 	/**
 	 * int(11)
-	 *
+	 * 
 	 * @var integer
 	 */
 	var $code      			= NULL;
 
 	/**
 	 * varchar(200)
-	 *
+	 * 
 	 * @var string
 	 */
 	var $title				= NULL;
 
 	/**
 	 * varchar(200)
-	 *
+	 * 
 	 * @var string
 	 */
 	var $companyName		= NULL;
 
 	/**
 	 * varchar(200)
-	 *
+	 * 
 	 * @var string
 	 */
 	var $companyLocation	= NULL;
 
 	/**
 	 * varchar(100)
-	 *
+	 * 
 	 * @var string
 	 */
 	var $companyLocationCountry	= NULL;
 
 	/**
 	 * varchar(200)
-	 *
+	 * 
 	 * @var string
 	 */
 	var $companyWebsite		= NULL;
 
 	/**
 	 * text
-	 *
+	 * 
 	 * @var string
 	 */
 	var $description		= NULL;
 
 	/**
 	 * int(50)
-	 *
+	 * 
 	 * @var integer
 	 */
 	var $addedBy 			= NULL;
 
 	/**
 	 * int(50)
-	 *
+	 * 
 	 * @var integer
 	 */
 	var $editedBy 			= NULL;
 
 	/**
 	 * datetime (0000-00-00 00:00:00)
-	 *
+	 * 
 	 * @var string
 	 */
 	var $added    			= NULL;
 
 	/**
 	 * datetime (0000-00-00 00:00:00)
-	 *
+	 * 
 	 * @var string
 	 */
 	var $edited	    		= NULL;
 
 	/**
 	 * int(11)
-	 *
+	 * 
 	 * @var integer
 	 */
 	var $status				= NULL;
 
 	/**
 	 * int(3)
-	 *
+	 * 
 	 * 0 pending approval
 	 * 1 published
 	 * 2 deleted
@@ -156,63 +156,63 @@ class Job extends JTable
 
 	/**
 	 * datetime (0000-00-00 00:00:00)
-	 *
+	 * 
 	 * @var string
 	 */
 	var $opendate    		= NULL;
 
 	/**
 	 * datetime (0000-00-00 00:00:00)
-	 *
+	 * 
 	 * @var string
 	 */
 	var $closedate    		= NULL;
 
 	/**
 	 * datetime (0000-00-00 00:00:00)
-	 *
+	 * 
 	 * @var string
 	 */
 	var $startdate    		= NULL;
 
 	/**
 	 * varchar(250)
-	 *
+	 * 
 	 * @var string
 	 */
 	var $applyExternalUrl	= NULL;
 
 	/**
 	 * varchar(50)
-	 *
+	 * 
 	 * @var string
 	 */
 	var $applyInternal 		= NULL;
 
 	/**
 	 * varchar(100)
-	 *
+	 * 
 	 * @var string
 	 */
 	var $contactName		= NULL;
 
 	/**
 	 * varchar(100)
-	 *
+	 * 
 	 * @var string
 	 */
 	var $contactEmail		= NULL;
 
 	/**
 	 * varchar(100)
-	 *
+	 * 
 	 * @var string
 	 */
 	var $contactPhone		= NULL;
 
 	/**
 	 * Constructor
-	 *
+	 * 
 	 * @param      object &$db JDatabase
 	 * @return     void
 	 */
@@ -223,18 +223,18 @@ class Job extends JTable
 
 	/**
 	 * Validate data
-	 *
+	 * 
 	 * @return     boolean True if data is valid
 	 */
 	public function check()
 	{
-		if (trim($this->title) == '')
+		if (trim($this->title) == '') 
 		{
 			$this->setError(JText::_('ERROR_MISSING_JOB_TITLE'));
 			return false;
 		}
 
-		if (trim($this->companyName) == '')
+		if (trim($this->companyName) == '') 
 		{
 			$this->setError(JText::_('ERROR_MISSING_EMPLOYER_NAME'));
 			return false;
@@ -245,7 +245,7 @@ class Job extends JTable
 
 	/**
 	 * Get a user's openings
-	 *
+	 * 
 	 * @param      integer $uid     User ID
 	 * @param      integer $current Get current?
 	 * @param      integer $admin   Admin access?
@@ -254,19 +254,19 @@ class Job extends JTable
 	 */
 	public function get_my_openings($uid = NULL, $current = 0, $admin = 0, $active = 0)
 	{
-		if ($uid === NULL)
+		if ($uid === NULL) 
 		{
-			$juser 	= JFactory::getUser();
-			$uid 	= $juser->get('id');
+			$juser =& JFactory::getUser();
+			$uid = $juser->get('id');
 		}
 
 		$sql  = "SELECT j.id, j.title, j.status, j.added, j.code, ";
-		$sql .= $current ? "(SELECT j.id FROM $this->_tbl AS j WHERE j.id=" . $this->_db->Quote($current) . ") as current, " : "0 as current, ";
+		$sql .= $current ? "(SELECT j.id FROM  $this->_tbl AS j WHERE j.id=$current) as current, " : "0 as current, ";
 		$sql .= "(SELECT count(*) FROM  #__jobs_applications AS a WHERE a.jid=j.id AND a.status=1) as applications ";
-		$sql .= " FROM $this->_tbl AS j ";
-		$sql .= " WHERE  j.status!=2 ";
-		$sql .= $active ? " AND  j.status!=3 " : "";
-		$sql .= $admin ? " AND j.employerid=1 " : " AND j.employerid=" . $this->_db->Quote($uid) . " ";
+		$sql .= "\n FROM $this->_tbl AS j ";
+		$sql .= "\n WHERE  j.status!=2 ";
+		$sql .= $active ? "\n AND  j.status!=3 " : "";
+		$sql .= $admin ? "\n AND j.employerid=1 " : "\n AND j.employerid='$uid' ";
 		$sql .= " ORDER BY j.status ASC";
 
 		$this->_db->setQuery($sql);
@@ -275,9 +275,9 @@ class Job extends JTable
 
 	/**
 	 * Short description for 'countMyActiveOpenings'
-	 *
+	 * 
 	 * Long description (if any) ...
-	 *
+	 * 
 	 * @param      unknown $uid Parameter description (if any) ...
 	 * @param      integer $onlypublished Parameter description (if any) ...
 	 * @param      mixed $admin Parameter description (if any) ...
@@ -285,22 +285,22 @@ class Job extends JTable
 	 */
 	public function countMyActiveOpenings($uid = NULL, $onlypublished = 0, $admin = 0)
 	{
-		if ($uid === NULL)
+		if ($uid === NULL) 
 		{
-			$juser 	= JFactory::getUser();
-			$uid 	= $juser->get('id');
+			$juser =& JFactory::getUser();
+			$uid = $juser->get('id');
 		}
 
 		$sql  = "SELECT count(*) FROM $this->_tbl AS j ";
-		if ($onlypublished)
+		if ($onlypublished) 
 		{
-			$sql .= " WHERE  j.status=1 ";
-		}
-		else
+			$sql .= "\n WHERE  j.status=1 ";
+		} 
+		else 
 		{
-			$sql .= " WHERE  j.status!=2 AND  j.status!=3 ";
+			$sql .= "\n WHERE  j.status!=2 AND  j.status!=3 ";
 		}
-		$sql .= $admin ? " AND j.employerid=1 " : " AND j.employerid=" . $this->_db->Quote($uid) . " ";
+		$sql .= $admin ? "\n AND j.employerid=1 " : "\n AND j.employerid='$uid' ";
 
 		$this->_db->setQuery($sql);
 		return $this->_db->loadResult();
@@ -308,7 +308,7 @@ class Job extends JTable
 
 	/**
 	 * Get job openings
-	 *
+	 * 
 	 * @param      array   $filters      Filters to build query from
 	 * @param      integer $uid          User ID
 	 * @param      itneger $admin        Admin access?
@@ -319,8 +319,8 @@ class Job extends JTable
 	{
 		$defaultsort = isset($filters['defaultsort']) && $filters['defaultsort'] == 'type' ? 'type' : 'category';
 		$category    = isset($filters['category']) ? $filters['category'] : 'all';
-		$now 		 = JFactory::getDate()->toSql();
-		$juser 		 = JFactory::getUser();
+		$now = date('Y-m-d H:i:s', time());
+		$juser =& JFactory::getUser();
 		$filters['start'] = isset($filters['start']) ? $filters['start'] : 0;
 		$active = isset($filters['active']) && $filters['active'] == 1 ? 1 : 0;
 
@@ -345,12 +345,10 @@ class Job extends JTable
 								break;
 			case 'title':    	$sort .= 'j.title ' . $sortdir . ' ';
 								break;
-			case 'location':    $sort .= 'j.companyName ' . $sortdir . ', j.companyLocation ' . $sortdir;
-								break;
 			case 'adminposting':$sort .= 'j.employerid ' . $sortdir . ' ';
 								break;
-			default: 			$sort .= $defaultsort=='type'
-								? 'j.type ASC, j.status ASC, j.opendate DESC'
+			default: 			$sort .= $defaultsort=='type' 
+								? 'j.type ASC, j.status ASC, j.opendate DESC' 
 								: 'c.ordernum ASC, j.status ASC, j.opendate DESC ';
 								break;
 		}
@@ -359,66 +357,66 @@ class Job extends JTable
 		{
 			$sql = "SELECT COUNT(*) ";
 		}
-		else
+		else 
 		{
 			$sql  = "SELECT DISTINCT j.id, j.*, c.category AS categoryname, c.category IS NULL AS isnull, j.type=0 as typenull, ";
 
 			$sql .= $admin ? "s.expires  AS inactive,  " : ' NULL AS inactive, ';
-			if ($uid)
+			if ($uid) 
 			{
-				$sql.= "\n (SELECT count(*) FROM #__jobs_admins AS B WHERE B.jid=j.id AND B.uid=" . $this->_db->Quote($uid) . ") AS manager,";
-			}
-			else
+				$sql.= "\n (SELECT count(*) FROM #__jobs_admins AS B WHERE B.jid=j.id AND B.uid=" . $uid . ") AS manager,";
+			} 
+			else 
 			{
 				$sql.= "\n NULL AS manager,";
 			}
 			$sql.= "\n (SELECT count(*) FROM #__jobs_applications AS a WHERE a.jid=j.id) AS applications,";
-			if (!$juser->get('guest'))
+			if (!$juser->get('guest')) 
 			{
 				$myid = $juser->get('id');
-				$sql .= "\n (SELECT a.applied FROM #__jobs_applications AS a WHERE a.jid=j.id AND a.uid=" . $this->_db->Quote($myid) . " AND a.status=1) AS applied,";
-				$sql .= "\n (SELECT a.withdrawn FROM #__jobs_applications AS a WHERE a.jid=j.id AND a.uid=" . $this->_db->Quote($myid) . " AND a.status=2) AS withdrawn,";
-			}
-			else
+				$sql .= "\n (SELECT a.applied FROM #__jobs_applications AS a WHERE a.jid=j.id AND a.uid='$myid' AND a.status=1) AS applied,";
+				$sql .= "\n (SELECT a.withdrawn FROM #__jobs_applications AS a WHERE a.jid=j.id AND a.uid='$myid' AND a.status=2) AS withdrawn,";
+			} 
+			else 
 			{
 				$sql .= "\n NULL AS applied,";
 				$sql .= "\n NULL AS withdrawn,";
 			}
 			$sql .= "\n (SELECT t.category FROM #__jobs_types AS t WHERE t.id=j.type) AS typename ";
 
-			if (trim($filters['search']))
+			if (trim($filters['search'])) 
 			{
 				$words   = explode(',', $filters['search']);
 				$s = array();
 				foreach ($words as $word)
 				{
-					if (trim($word) != '')
+					if (trim($word) != '') 
 					{
 						$s[] = trim($word);
 					}
 				}
 
-				if (count($s) > 0)
+				if (count($s) > 0) 
 				{
 					$kw = 0;
 					for ($i=0, $n=count($s); $i < $n; $i++)
 					{
 						$sql .= "\n , (SELECT count(*) FROM $this->_tbl AS o WHERE o.id=j.id ";
-						$sql .= "AND  LOWER(o.title) LIKE " . $this->_db->quote('%' . $s[$i] . '%') . ") AS keyword$i ";
+						$sql .= "AND  LOWER(o.title) LIKE '%$s[$i]%') AS keyword$i ";
 						$sql .= "\n , (SELECT count(*) FROM $this->_tbl AS o WHERE o.id=j.id ";
-						$sql .= "AND  LOWER(o.description) LIKE " . $this->_db->quote('%' . $s[$i] . '%') . ") AS bodykeyword$i ";
+						$sql .= "AND  LOWER(o.description) LIKE '%$s[$i]%') AS bodykeyword$i ";
 						$kw .= '+ keyword' . $i . ' * 2 ';
 						$kw .= '+ bodykeyword' . $i;
 					}
 
 					$sql .= "\n , (SELECT " . $kw . ") AS keywords ";
-				}
-				else
+				} 
+				else 
 				{
 					$sql .= "\n , (SELECT 0) AS keywords ";
 				}
-			}
-			else
+			} 
+			else 
 			{
 				$sql .= "\n , (SELECT 0) AS keywords ";
 			}
@@ -432,26 +430,26 @@ class Job extends JTable
 		$sql .= "LEFT JOIN #__users_points_subscriptions AS s ON s.id=e.subscriptionid AND s.uid=e.uid ";
 		$sql .= " WHERE ";
 		// only show active ads
-		$sql .= $admin ? "\n  j.status!=2" : "\n  j.status=1 AND s.status=1 AND s.expires > " . $this->_db->Quote($now) . " ";
+		$sql .= $admin ? "\n  j.status!=2" : "\n  j.status=1 AND s.status=1 AND s.expires > '" . $now . "' ";
 
 		if ($category!='all') {
-			$sql .= "\n AND j.cid=" . $this->_db->Quote($category);
+			$sql .= "\n AND j.cid='" . $category . "'";
 		}
-		if ($subscription)
+		if ($subscription) 
 		{
-			$sql .= "\n AND s.code=" . $this->_db->Quote($subscription);
+			$sql .= "\n AND s.code='" . $subscription . "'";
 		}
-		if ($active)
+		if ($active) 
 		{
-			$sql .= "\n AND (j.closedate ='0000-00-00 00:00:00' OR j.closedate IS NULL OR j.closedate > " . $this->_db->Quote($now) . ") ";
+			$sql .= "\n AND (j.closedate ='0000-00-00 00:00:00' OR j.closedate IS NULL OR j.closedate > '" . $now . "') ";
 		}
-
+		
 		if (!$count)
 		{
 			$sql .= " ORDER BY ". $sort;
 		}
 
-		if (!$count && isset ($filters['limit']) && $filters['limit']!=0)
+		if (!$count && isset ($filters['limit']) && $filters['limit']!=0) 
 		{
 			$sql .= " LIMIT " . $filters['start'] . ", " . $filters['limit'];
 		}
@@ -462,19 +460,19 @@ class Job extends JTable
 
 	/**
 	 * Load a record and bind to $this
-	 *
+	 * 
 	 * @param      string $code Job code
 	 * @return     boolean True upon success
 	 */
 	public function loadJob($code=NULL)
 	{
-		if ($code === NULL)
+		if ($code === NULL) 
 		{
 			return false;
 		}
 
-		$this->_db->setQuery("SELECT * FROM $this->_tbl WHERE code=" . $this->_db->Quote($code) . " LIMIT 1");
-		if ($result = $this->_db->loadAssoc())
+		$this->_db->setQuery("SELECT * FROM $this->_tbl WHERE code='$code' LIMIT 1");
+		if ($result = $this->_db->loadAssoc()) 
 		{
 			return $this->bind($result);
 		}
@@ -483,24 +481,24 @@ class Job extends JTable
 
 	/**
 	 * Delete an open job
-	 *
+	 * 
 	 * @param      integer $jid Job ID
 	 * @return     boolean True upon success
 	 */
 	public function delete_opening($jid)
 	{
-		if ($jid === NULL)
+		if ($jid === NULL) 
 		{
 			$jid == $this->id;
 		}
-		if ($jid === NULL)
+		if ($jid === NULL) 
 		{
 			return false;
 		}
 
-		$query  = "UPDATE $this->_tbl SET status='2' WHERE id=" . $this->_db->Quote($jid);
+		$query  = "UPDATE $this->_tbl SET status='2' WHERE id=" . $jid;
 		$this->_db->setQuery($query);
-		if (!$this->_db->query())
+		if (!$this->_db->query()) 
 		{
 			$this->setError($this->_db->getErrorMsg());
 			return false;
@@ -510,7 +508,7 @@ class Job extends JTable
 
 	/**
 	 * Get job opening
-	 *
+	 * 
 	 * @param      integer $jid     Job ID
 	 * @param      integer $uid     User ID
 	 * @param      integer $admin   Admin access?
@@ -519,24 +517,24 @@ class Job extends JTable
 	 */
 	public function get_opening($jid = 0, $uid = 0, $admin = 0, $jobcode = '')
 	{
-		if ($jid === NULL && $jobcode == '')
+		if ($jid === NULL && $jobcode == '') 
 		{
 			return false;
 		}
 
-		$now 	= JFactory::getDate()->toSql();
-		$juser 	= JFactory::getUser();
-		$myid 	= $juser->get('id');
+		$now = date('Y-m-d H:i:s', time());
+		$juser =& JFactory::getUser();
+		$myid = $juser->get('id');
 
 		$sql  = "SELECT j.*, ";
 		$sql .= $admin ? "s.expires IS NULL AS inactive,  " : ' NULL AS inactive, ';
 		$sql .= "\n (SELECT count(*) FROM #__jobs_applications AS a WHERE a.jid=j.id) AS applications,";
-		if (!$juser->get('guest'))
+		if (!$juser->get('guest')) 
 		{
-			$sql .= "\n (SELECT a.applied FROM #__jobs_applications AS a WHERE a.jid=j.id AND a.uid=" . $this->_db->Quote($myid) . " AND a.status=1) AS applied,";
-			$sql .= "\n (SELECT a.withdrawn FROM #__jobs_applications AS a WHERE a.jid=j.id AND a.uid=" . $this->_db->Quote($myid) . " AND a.status=2) AS withdrawn,";
-		}
-		else
+			$sql .= "\n (SELECT a.applied FROM #__jobs_applications AS a WHERE a.jid=j.id AND a.uid='$myid' AND a.status=1) AS applied,";
+			$sql .= "\n (SELECT a.withdrawn FROM #__jobs_applications AS a WHERE a.jid=j.id AND a.uid='$myid' AND a.status=2) AS withdrawn,";
+		} 
+		else 
 		{
 			$sql .= "\n NULL AS applied,";
 			$sql .= "\n NULL AS withdrawn,";
@@ -545,27 +543,27 @@ class Job extends JTable
 		$sql .= "\n FROM $this->_tbl AS j";
 		$sql .= $admin ? "\n LEFT JOIN #__jobs_employers AS e ON e.uid=j.employerid " : "\n JOIN #__jobs_employers AS e ON e.uid=j.employerid ";
 		$sql .= "LEFT JOIN #__users_points_subscriptions AS s ON s.id=e.subscriptionid AND s.uid=e.uid ";
-		$sql .= "AND s.status=1 AND s.expires > " . $this->_db->Quote($now) . " WHERE ";
+		$sql .= "AND s.status=1 AND s.expires > '" . $now . "' WHERE ";
 
-		if ($admin)
+		if ($admin) 
 		{
 			$sql .= " j.status != 2 ";
-		}
-		else if ($uid)
+		} 
+		else if ($uid) 
 		{
-			$sql .= "\n  (j.status=1 OR (j.status != 1 AND j.status!=2 AND j.employerid = " . $this->_db->Quote($uid) . ")) ";
-		}
-		else
+			$sql .= "\n  (j.status=1 OR (j.status != 1 AND j.status!=2 AND j.employerid = '$uid')) ";
+		} 
+		else 
 		{
 			$sql .= " j.status = 1 ";
 		}
-		if ($jid)
+		if ($jid) 
 		{
-			$sql .= "\n AND j.id=" . $this->_db->Quote($jid);
-		}
-		else if ($jobcode)
+			$sql .= "\n AND j.id='$jid'";
+		} 
+		else if ($jobcode) 
 		{
-			$sql .= "\n AND j.code=" . $this->_db->Quote($jobcode);
+			$sql .= "\n AND j.code='$jobcode'";
 		}
 
 		$this->_db->setQuery($sql);
