@@ -30,32 +30,30 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die('Restricted access');
 
-$canDo = WishlistHelperPermissions::getActions('component');
+$canDo = WishlistHelper::getActions('component');
 
-JToolBarHelper::title(JText::_('COM_WISHLIST') . ': ' . JText::_('COM_WISHLIST_COMMENTS'), 'wishlist.png');
-if ($canDo->get('core.edit.state'))
+JToolBarHelper::title('<a href="index.php?option=com_wishlist">' . JText::_('Wishlist Manager') . '</a>', 'wishlist.png');
+if ($canDo->get('core.edit.state')) 
 {
 	JToolBarHelper::publishList();
 	JToolBarHelper::unpublishList();
 	JToolBarHelper::spacer();
 }
-if ($canDo->get('core.create'))
+if ($canDo->get('core.create')) 
 {
 	JToolBarHelper::addNew();
 }
-if ($canDo->get('core.edit'))
+if ($canDo->get('core.edit')) 
 {
 	JToolBarHelper::editList();
 }
-if ($canDo->get('core.delete'))
+if ($canDo->get('core.delete')) 
 {
 	JToolBarHelper::deleteList();
 }
-JToolBarHelper::spacer();
-JToolBarHelper::help('comments');
 ?>
 <script type="text/javascript">
-function submitbutton(pressbutton)
+function submitbutton(pressbutton) 
 {
 	var form = document.adminForm;
 	if (pressbutton == 'cancel') {
@@ -69,8 +67,8 @@ function submitbutton(pressbutton)
 
 <form action="index.php" method="post" name="adminForm" id="adminForm">
 	<fieldset id="filter-bar">
-		<label for="filter_search"><?php echo JText::_('COM_WISHLIST_SEARCH'); ?>:</label>
-		<input type="text" name="search" id="filter_search" value="<?php echo $this->escape($this->filters['search']); ?>" placeholder="<?php echo JText::_('COM_WISHLIST_SEARCH_PLACEHOLDER'); ?>" />
+		<label for="filter_search"><?php echo JText::_('COM_WISHLIST_SEARCH'); ?>:</label> 
+		<input type="text" name="search" id="filter_search" value="<?php echo $this->filters['search']; ?>" />
 
 		<input type="submit" value="<?php echo JText::_('COM_WISHLIST_GO'); ?>" />
 	</fieldset>
@@ -78,30 +76,28 @@ function submitbutton(pressbutton)
 
 	<table class="adminlist">
 		<thead>
-		<?php if ($this->filters['wish'] > 0) { ?>
 			<tr>
 				<th colspan="7">
 					<a href="index.php?option=<?php echo $this->option ?>&amp;controller=wishes&amp;wishlist=<?php echo $this->wishlist->id; ?>">
-						(<?php echo $this->escape(stripslashes($this->wishlist->category)); ?>) &nbsp;
-						<?php echo $this->escape(stripslashes($this->wishlist->title)); ?> &nbsp;&rsaquo;&nbsp;
+						(<?php echo $this->escape(stripslashes($this->wishlist->category)); ?>) &nbsp; 
+						<?php echo $this->escape(stripslashes($this->wishlist->title)); ?> &nbsp;&rsaquo;&nbsp; 
 					</a>
 					<?php echo $this->escape(stripslashes($this->wish->subject)); ?>
 				</th>
 			</tr>
-		<?php } ?>
 			<tr>
 				<th scope="col"><input type="checkbox" name="toggle" value="" onclick="checkAll(<?php echo count($this->rows);?>);" /></th>
-				<th scope="col"><?php echo JHTML::_('grid.sort', 'COM_WISHLIST_COMMENT_ID', 'id', @$this->filters['sort_Dir'], @$this->filters['sort']); ?></th>
-				<th scope="col"><?php echo JHTML::_('grid.sort', 'COM_WISHLIST_COMMENT', 'comment', @$this->filters['sort_Dir'], @$this->filters['sort']); ?></th>
-				<th scope="col"><?php echo JHTML::_('grid.sort', 'COM_WISHLIST_ADDED_BY', 'added_by', @$this->filters['sort_Dir'], @$this->filters['sort']); ?></th>
-				<th scope="col"><?php echo JHTML::_('grid.sort', 'COM_WISHLIST_ADDED', 'added', @$this->filters['sort_Dir'], @$this->filters['sort']); ?></th>
-				<th scope="col"><?php echo JHTML::_('grid.sort', 'COM_WISHLIST_STATE', 'status', @$this->filters['sort_Dir'], @$this->filters['sort']); ?></th>
-				<th scope="col"><?php echo JHTML::_('grid.sort', 'COM_WISHLIST_ANONYMOUS', 'anonymous', @$this->filters['sort_Dir'], @$this->filters['sort']); ?></th>
+				<th scope="col"><?php echo JHTML::_('grid.sort', JText::_('COM_WISHLIST_COMMENT_ID'), 'id', @$this->filters['sort_Dir'], @$this->filters['sort']); ?></th>
+				<th scope="col"><?php echo JHTML::_('grid.sort', JText::_('COM_WISHLIST_COMMENT'), 'comment', @$this->filters['sort_Dir'], @$this->filters['sort']); ?></th>
+				<th scope="col"><?php echo JHTML::_('grid.sort', JText::_('COM_WISHLIST_ADDED_BY'), 'added_by', @$this->filters['sort_Dir'], @$this->filters['sort']); ?></th>
+				<th scope="col"><?php echo JHTML::_('grid.sort', JText::_('COM_WISHLIST_ADDED'), 'added', @$this->filters['sort_Dir'], @$this->filters['sort']); ?></th>
+				<th scope="col"><?php echo JHTML::_('grid.sort', JText::_('COM_WISHLIST_STATE'), 'status', @$this->filters['sort_Dir'], @$this->filters['sort']); ?></th>
+				<th scope="col"><?php echo JHTML::_('grid.sort', JText::_('COM_WISHLIST_ANONYMOUS'), 'anonymous', @$this->filters['sort_Dir'], @$this->filters['sort']); ?></th>
 			</tr>
 		</thead>
 		<tfoot>
  			<tr>
- 				<td colspan="7"><?php echo $this->pageNav->getListFooter(); ?></td>
+ 				<td colspan="8"><?php echo $this->pageNav->getListFooter(); ?></td>
  			</tr>
 		</tfoot>
 		<tbody>
@@ -129,21 +125,21 @@ for ($i=0, $n=count($this->rows); $i < $n; $i++)
 		break;
 	}
 
-	if ($row->anonymous)
+	if ($row->anonymous) 
 	{
 		$aclass = 'publish';
-		$atask = 'publicize';
-		$aalt = JText::_('COM_WISHLIST_ANONYMOUS');
-	}
-	else
+		$atask = 'unpublish';
+		$aalt = JText::_('Anonymous');
+	} 
+	else 
 	{
 		$aclass = 'unpublish';
-		$atask = 'anonymize';
-		$aalt = JText::_('COM_WISHLIST_NOT_ANONYMOUS');
+		$atask = 'publish';
+		$aalt = JText::_('Not anonymous');
 	}
 
-	$comment = substr(strip_tags(stripslashes($row->content)), 0, 50);
-	if (strlen($row->content) >= 50)
+	$comment = substr($row->comment, 0, 50);
+	if (strlen($row->comment) >= 50) 
 	{
 		$comment .= '...';
 	}
@@ -157,43 +153,43 @@ for ($i=0, $n=count($this->rows); $i < $n; $i++)
 				</td>
 				<td>
 					<?php echo $row->prfx; ?>
-					<?php if ($canDo->get('core.edit')) { ?>
-						<a href="<?php echo JRoute::_('index.php?option=' . $this->option . '&controller=' . $this->controller . '&task=edit&id=' . $row->id . '&wish=' . $row->wish); ?>">
-							<span><?php echo $this->escape($comment); ?></span>
-						</a>
-					<?php } else { ?>
-						<span>
-							<span><?php echo $this->escape($comment); ?></span>
-						</span>
-					<?php } ?>
+<?php if ($canDo->get('core.edit')) { ?>
+					<a href="index.php?option=<?php echo $this->option ?>&amp;controller=<?php echo $this->controller; ?>&amp;task=edit&amp;id[]=<?php echo $row->id; ?>&amp;wish=<?php echo $row->wish; ?>" title="<?php echo JText::_('COM_WISHLIST_EDIT_COMMENT'); ?>">
+						<span><?php echo $this->escape(stripslashes($comment)); ?></span>
+					</a>
+<?php } else { ?>
+					<span>
+						<span><?php echo $this->escape(stripslashes($comment)); ?></span>
+					</span>
+<?php } ?>
 				</td>
 				<td>
-					<?php echo $this->escape(stripslashes($row->name)); ?>
+					<?php echo $this->escape(stripslashes($row->authorname)); ?>
 				</td>
 				<td>
-					<time datetime="<?php echo $row->created; ?>"><?php echo $row->created; ?></time>
+					<time datetime="<?php echo $row->added; ?>"><?php echo $row->added; ?></time>
 				</td>
 				<td>
-					<?php if ($canDo->get('core.edit.state')) { ?>
-						<a class="state <?php echo $class; ?>" href="<?php echo JRoute::_('index.php?option=' . $this->option . '&controller=' . $this->controller . '&task=' . $task . '&id=' . $row->id . '&wish=' . $this->filters['wish'] . '&' . JUtility::getToken() . '=1'); ?>" title="<?php echo JText::sprintf('COM_WISHLIST_SET_TASK', $task);?>">
-							<span><?php echo $alt; ?></span>
-						</a>
-					<?php } else { ?>
-						<span class="state <?php echo $class; ?>">
-							<span><?php echo $alt; ?></span>
-						</span>
-					<?php } ?>
+<?php if ($canDo->get('core.edit.state')) { ?>
+					<a class="state <?php echo $class; ?>" href="index.php?option=<?php echo $this->option ?>&amp;controller=<?php echo $this->controller; ?>&amp;task=<?php echo $task;?>&amp;id[]=<?php echo $row->id; ?>&amp;wish=<?php echo $this->filters['wish']; ?>" title="<?php echo JText::sprintf('COM_WISHLIST_SET_TASK', $task);?>">
+						<span><?php echo $alt; ?></span>
+					</a>
+<?php } else { ?>
+					<span class="state <?php echo $class; ?>">
+						<span><?php echo $alt; ?></span>
+					</span>
+<?php } ?>
 				</td>
 				<td>
-					<?php if ($canDo->get('core.edit.state')) { ?>
-						<a class="<?php echo $aclass; ?> state" href="<?php echo JRoute::_('index.php?option=' . $this->option . '&controller=' . $this->controller . '&task=' . $atask . '&id=' . $row->id . '&wish=' . $row->wish . '&' . JUtility::getToken() . '=1'); ?>" title="<?php echo $aalt; ?>">
-							<span><?php echo $aalt; ?></span>
-						</a>
-					<?php } else { ?>
-						<span class="<?php echo $aclass; ?> state">
-							<span><?php echo $aalt; ?></span>
-						</span>
-					<?php } ?>
+<?php if ($canDo->get('core.edit.state')) { ?>
+					<a class="<?php echo $aclass; ?> state" href="index.php?option=<?php echo $this->option ?>&amp;controller=<?php echo $this->controller; ?>&amp;task=<?php echo $atask; ?>&amp;id=<?php echo $row->id; ?>&amp;wish=<?php echo $row->wish; ?>" title="<?php echo $aalt; ?>">
+						<span><?php echo $aalt; ?></span>
+					</a>
+<?php } else { ?>
+					<span class="<?php echo $aclass; ?> state">
+						<span><?php echo $aalt; ?></span>
+					</span>
+<?php } ?>
 				</td>
 			</tr>
 <?php
@@ -210,6 +206,6 @@ for ($i=0, $n=count($this->rows); $i < $n; $i++)
 	<input type="hidden" name="boxchecked" value="0" />
 	<input type="hidden" name="filter_order" value="<?php echo $this->filters['sort']; ?>" />
 	<input type="hidden" name="filter_order_Dir" value="<?php echo $this->filters['sort_Dir']; ?>" />
-
+	
 	<?php echo JHTML::_('form.token'); ?>
 </form>
