@@ -30,9 +30,6 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die('Restricted access');
 
-error_reporting(E_ALL);
-@ini_set('display_errors', '1');
-
 // Authorization check
 if (version_compare(JVERSION, '1.6', 'lt'))
 {
