@@ -34,60 +34,61 @@ defined('_JEXEC') or die;
 $app = JFactory::getApplication();
 $doc = JFactory::getDocument();
 
-$browser = new \Hubzero\Browser\Detector();
-$b = $browser->name();
-$v = $browser->major();
+ximport('Hubzero_Browser');
+$browser = new Hubzero_Browser();
+$b = $browser->getBrowser();
+$v = $browser->getBrowserMajorVersion();
+
+$juser =& JFactory::getUser();
 ?>
 <!DOCTYPE html>
 <!--[if lt IE 7 ]> <html dir="<?php echo $this->direction; ?>" lang="<?php echo $this->language; ?>" class="ie6"> <![endif]-->
 <!--[if IE 7 ]>    <html dir="<?php echo $this->direction; ?>" lang="<?php echo $this->language; ?>" class="ie7"> <![endif]-->
 <!--[if IE 8 ]>    <html dir="<?php echo $this->direction; ?>" lang="<?php echo $this->language; ?>" class="ie8"> <![endif]-->
 <!--[if IE 9 ]>    <html dir="<?php echo $this->direction; ?>" lang="<?php echo $this->language; ?>" class="ie9"> <![endif]-->
-<!--[if (gt IE 9)|!(IE)]><!--> <html dir="<?php echo $this->direction; ?>" lang="<?php echo $this->language; ?>" class="j25 <?php echo $b . ' ' . $b . $v; ?>"> <!--<![endif]-->
+<!--[if (gt IE 9)|!(IE)]><!--> <html dir="<?php echo $this->direction; ?>" lang="<?php echo $this->language; ?>" class="<?php echo $b . ' ' . $b . $v; ?>"> <!--<![endif]-->
 	<head>
-		<link href="<?php echo $this->baseurl; ?>/templates/<?php echo $this->template; ?>/css/template.css" rel="stylesheet" type="text/css" />
-		<link href="<?php echo $this->baseurl; ?>/templates/<?php echo $this->template; ?>/css/common/icons.css" rel="stylesheet" type="text/css" />
-		<link href="<?php echo $this->baseurl; ?>/templates/<?php echo $this->template; ?>/css/error.css" rel="stylesheet" type="text/css" />
+		<link href="templates/<?php echo $this->template; ?>/css/template.css" rel="stylesheet" type="text/css" />
+		<link href="templates/<?php echo $this->template; ?>/css/common/icons.css" rel="stylesheet" type="text/css" />
+		<link href="templates/<?php echo $this->template; ?>/css/error.css" rel="stylesheet" type="text/css" />
 <?php if ($this->direction == 'rtl') : ?>
-		<link href="<?php echo $this->baseurl; ?>/templates/<?php echo $this->template; ?>/css/common/rtl.css" rel="stylesheet" type="text/css" />
+		<link href="templates/<?php echo $this->template; ?>/css/common/rtl.css" rel="stylesheet" type="text/css" />
 <?php endif; ?>
-
+<?php if (JPluginHelper::isEnabled('system', 'debug')) { ?>
+		<link href="templates/<?php echo $this->template; ?>/css/common/debug.css" rel="stylesheet" type="text/css" />
+<?php } ?>
 <?php if ($b == 'firefox' && intval($v) < 4 && $browser->getBrowserMinorVersion() < 5) { ?>
-		<link href="<?php echo $this->baseurl; ?>/templates/<?php echo $this->template; ?>/css/browser/firefox.css" rel="stylesheet" type="text/css" />
+		<link href="templates/<?php echo $this->template; ?>/css/browser/firefox.css" rel="stylesheet" type="text/css" />
 <?php } ?>
 		<!--[if IE 7]>
-			<link href="<?php echo $this->baseurl; ?>/templates/<?php echo $this->template; ?>/css/browser/ie7.css" rel="stylesheet" type="text/css" />
-			<script src="<?php echo $this->baseurl; ?>/templates/<?php echo $this->template; ?>/js/html5.js" type="text/javascript"></script>
+			<link href="templates/<?php echo $this->template; ?>/css/browser/ie7.css" rel="stylesheet" type="text/css" />
+			<script src="templates/<?php echo $this->template; ?>/js/html5.js" type="text/javascript"></script>
 		<![endif]-->
 		<!--[if IE 8]>
-			<link href="<?php echo $this->baseurl; ?>/templates/<?php echo $this->template; ?>/css/browser/ie8.css" rel="stylesheet" type="text/css" />
-			<script src="<?php echo $this->baseurl; ?>/templates/<?php echo $this->template; ?>/js/html5.js" type="text/javascript"></script>
+			<link href="templates/<?php echo $this->template; ?>/css/browser/ie8.css" rel="stylesheet" type="text/css" />
+			<script src="templates/<?php echo $this->template; ?>/js/html5.js" type="text/javascript"></script>
 		<![endif]-->
 	</head>
 	<body id="error-body">
 		<header id="header" role="banner">
 			<h1><a href="<?php echo JURI::root(); ?>"><?php echo $app->getCfg('sitename'); ?></a></h1>
-
+			
 			<ul class="user-options">
 				<li>
 					<?php
 						//Display an harcoded logout
 						$task = JRequest::getCmd('task');
-						if ($task == 'edit' || $task == 'editA' || JRequest::getInt('hidemainmenu'))
-						{
+						if ($task == 'edit' || $task == 'editA' || JRequest::getInt('hidemainmenu')) {
 							$logoutLink = '';
-						}
-						else
-						{
-							$logoutLink = JRoute::_('index.php?option=com_login&task=logout&' . JUtility::getToken() . '=1');
+						} else {
+							$logoutLink = JRoute::_('index.php?option=com_login&task=logout&'. JUtility::getToken() .'=1');
 						}
 						$output = array();
 						// Print the Preview link to Main site.
-						//$juser = JFactory::getUser();
 						//$output[] = '<span class="viewsite"><a href="'.JURI::root().'" rel="external">'.JText::_('JGLOBAL_VIEW_SITE').'</a></span>';
 						//$output[] = '<span>' . $juser->get('name') .' (' . $juser->get('username') . ')</span>';
 						// Print the logout link.
-						$output[] = '<a class="logout" href="' . $logoutLink . '">' . JText::_('TPL_HUBBASICADMIN_LOGOUT') . '</a>';
+						$output[] = '<a class="logout" href="'.$logoutLink.'">'.JText::_('Log out').'</a>';
 						// Reverse rendering order for rtl display.
 						if ($this->direction == "rtl") :
 							$output = array_reverse($output);
@@ -99,10 +100,10 @@ $v = $browser->major();
 					?>
 				</li>
   			</ul>
-
+			
 			<div class="clear"></div>
 		</header><!-- / header -->
-
+		
 		<div id="wrap">
 			<nav role="navigation" class="main-navigation">
 				<div class="inner-wrap">
@@ -113,14 +114,14 @@ $v = $browser->major();
 				</div>
 				<div class="clr"><!-- We need this for the drop downs --></div>
 			</nav><!-- / .navigation -->
-
+						
 			<section id="component-content">
 				<div id="toolbar-box" class="toolbar-box">
 					<div class="header icon-48-alert">
 						<?php echo JText::_('An error has occurred'); ?>
 					</div>
 				</div><!-- / #toolbar-box -->
-
+				
 				<div id="errorbox">
 					<div class="col width-50 fltlft">
 						<h3><?php echo $this->error->getCode() ?></h3>
@@ -130,24 +131,24 @@ $v = $browser->major();
 					</div>
 					<div class="clr"></div>
 				</div>
-
+				
 				<?php if ($this->debug) :
 					echo $this->renderBacktrace();
 				endif; ?>
-
+				
 				<noscript>
 					<?php echo JText::_('JGLOBAL_WARNJAVASCRIPT') ?>
 				</noscript>
 			</section>
 		</div>
-
+		
 		<footer id="footer">
 			<section class="basement">
 				<p class="copyright">
-					<?php echo JText::sprintf('TPL_HUBBASICADMIN_COPYRIGHT', '<a href="' . JURI::root() . '">'. $app->getCfg('sitename') . '</a>', date("Y")); ?>
+					<?php echo $app->getCfg('sitename'); ?></a> &copy; <?php echo date("Y"); ?>. All Rights Reserved.
 				</p>
 				<p class="promotion">
-					<?php echo JText::sprintf('TPL_HUBBASICADMIN_POWERED_BY', \Hubzero\Version\Version::VERSION); ?>
+					<a rel="external" href="http://hubzero.org">Powered by <a href="http://hubzero.org">HUBzero&reg; CMS</a>.</a>
 				</p>
 			</section><!-- / .basement -->
 		</footer><!-- / #footer -->
