@@ -31,96 +31,122 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die('Restricted access');
 
-require_once(JPATH_ROOT . DS . 'components' . DS . 'com_collections' . DS . 'models' . DS . 'post.php');
+ximport('Hubzero_Controller');
+require_once(JPATH_ROOT . DS . 'components' . DS . 'com_collections' . DS . 'models' . DS . 'asset.php');
+require_once(JPATH_ROOT . DS . 'components' . DS . 'com_collections' . DS . 'models' . DS . 'item.php');
 
 /**
- * Collections controller class for media
+ * Wiki controller class for media
  */
-class CollectionsControllerMedia extends \Hubzero\Component\SiteController
+class CollectionsControllerMedia extends Hubzero_Controller
 {
 	/**
-	 * Download a file
-	 *
+	 * Download a wiki file
+	 * 
 	 * @return     void
 	 */
 	public function downloadTask()
 	{
-		$file = JRequest::getVar('file', '');
-		$item = JRequest::getInt('post', 0);
-		$size = JRequest::getWord('size', '');
+		// Get some needed libraries
+		ximport('Hubzero_Content_Server');
 
-		$post = CollectionsModelPost::getInstance($item);
+		$file = JRequest::getVar('file', '');
 
 		// Instantiate an attachment object
-		$asset = CollectionsModelAsset::getInstance($file, $post->get('item_id'));
+		$asset = CollectionsModelAsset::getInstance($file);
 
-		// Ensure record exist
-		if (!$asset->get('id') || $post->item()->get('state') == 2)
+		// Load the page
+		if (!$asset->get('item_id')) 
 		{
-			JError::raiseError(404, JText::_('COM_COLLECTIONS_FILE_NOT_FOUND'));
+			JError::raiseError(404, JText::_('COM_COLLECTIONS_PAGE_NOT_FOUND'));
 			return;
 		}
 
 		// Check authorization
-		if ($post->collection()->get('access') == 4 && $this->juser->get('guest'))
-		{
-			JError::raiseError(403, JText::_('COM_COLLECTIONS_ERROR_ACCESS_DENIED_TO_FILE'));
-			return;
-		}
-
-		// Check authorization
-		if (!$post->collection()->canAccess($this->juser->get('id')))
-		{
-			JError::raiseError(403, JText::_('COM_COLLECTIONS_ERROR_ACCESS_DENIED_TO_FILE'));
-			return;
-		}
 
 		// Ensure we have a path
-		if (!$asset->get('filename'))
+		if (!$asset->get('filename')) 
 		{
 			JError::raiseError(404, JText::_('COM_COLLECTIONS_FILE_NOT_FOUND'));
 			return;
 		}
-
-		$file = $asset->file($size);
+		if (preg_match("/^\s*http[s]{0,1}:/i", $asset->get('filename'))) 
+		{
+			JError::raiseError(404, JText::_('COM_COLLECTIONS_BAD_FILE_PATH'));
+			return;
+		}
+		if (preg_match("/^\s*[\/]{0,1}index.php\?/i", $asset->get('filename'))) 
+		{
+			JError::raiseError(404, JText::_('COM_COLLECTIONS_BAD_FILE_PATH'));
+			return;
+		}
+		// Disallow windows drive letter
+		if (preg_match("/^\s*[.]:/", $asset->get('filename'))) 
+		{
+			JError::raiseError(404, JText::_('COM_COLLECTIONS_BAD_FILE_PATH'));
+			return;
+		}
+		// Disallow \
+		if (strpos('\\', $asset->get('filename'))) 
+		{
+			JError::raiseError(404, JText::_('COM_COLLECTIONS_BAD_FILE_PATH'));
+			return;
+		}
+		// Disallow ..
+		if (strpos('..', $asset->get('filename'))) 
+		{
+			JError::raiseError(404, JText::_('COM_COLLECTIONS_BAD_FILE_PATH'));
+			return;
+		}
 
 		// Get the configured upload path
-		$filename = $asset->filespace() . DS . $asset->get('item_id') . DS . ltrim($file, DS);
+		$base_path = DS . trim($this->config->get('filepath', '/site/collections'), DS) . DS . $asset->get('item_id');
+
+		// Does the path start with a slash?
+		$asset->set('filename', DS . ltrim($asset->get('filename'), DS));
+
+		// Does the beginning of the $attachment->path match the config path?
+		if (substr($asset->get('filename'), 0, strlen($base_path)) == $base_path) 
+		{
+			// Yes - this means the full path got saved at some point
+		} 
+		else 
+		{
+			// No - append it
+			$asset->set('filename', $base_path . $asset->get('filename'));
+		}
+
+		// Add JPATH_ROOT
+		$filename = JPATH_ROOT . $asset->get('filename');
 
 		// Ensure the file exist
-		if (!file_exists($filename))
+		if (!file_exists($filename)) 
 		{
 			JError::raiseError(404, JText::_('COM_COLLECTIONS_FILE_NOT_FOUND') . ' ' . $filename);
 			return;
 		}
 
-		jimport('joomla.filesystem.file');
-		$ext = strtolower(JFile::getExt($filename));
-
 		// Initiate a new content server and serve up the file
-		$xserver = new \Hubzero\Content\Server();
+		$xserver = new Hubzero_Content_Server();
 		$xserver->filename($filename);
-		$xserver->disposition('attachment');
-		if (in_array($ext, array('jpg','jpeg','jpe','png','gif')))
-		{
-			$xserver->disposition('inline');
-		}
+		$xserver->disposition('inline');
 		$xserver->acceptranges(false); // @TODO fix byte range support
 
-		if (!$xserver->serve())
+		if (!$xserver->serve()) 
 		{
 			// Should only get here on error
 			JError::raiseError(404, JText::_('COM_COLLECTIONS_SERVER_ERROR'));
-		}
-		else
+		} 
+		else 
 		{
 			exit;
 		}
+		return;
 	}
 
 	/**
 	 * Upload a file to the wiki
-	 *
+	 * 
 	 * @return     void
 	 */
 	public function createTask()
@@ -131,7 +157,7 @@ class CollectionsControllerMedia extends \Hubzero\Component\SiteController
 		}
 
 		// Check if they're logged in
-		if ($this->juser->get('guest'))
+		if ($this->juser->get('guest')) 
 		{
 			$this->displayTask();
 			return;
@@ -139,7 +165,7 @@ class CollectionsControllerMedia extends \Hubzero\Component\SiteController
 
 		// Ensure we have an ID to work with
 		$listdir = JRequest::getInt('dir', 0, 'post');
-		if (!$listdir)
+		if (!$listdir) 
 		{
 			$this->setError(JText::_('COM_COLLECTIONS_NO_ID'));
 			$this->displayTask();
@@ -149,17 +175,12 @@ class CollectionsControllerMedia extends \Hubzero\Component\SiteController
 		if (substr($listdir, 0, 3) == 'tmp')
 		{
 			$item = new CollectionsModelItem($listdir);
-			if (!$item->exists())
+			$item->set('state', 0);
+			$item->set('description', $listdir);
+			if ($item->store())
 			{
-				$item->set('state', 0);
-				$item->set('access', 0);
-				$item->set('title', $listdir);
-				if (!$item->store())
-				{
-					$this->setError($item->getError());
-				}
+				$listdir = $item->get('id');
 			}
-			$listdir = $item->get('id');
 		}
 
 		// Create database entry
@@ -170,7 +191,7 @@ class CollectionsControllerMedia extends \Hubzero\Component\SiteController
 		$asset->set('state', 1);
 		$asset->set('type', 'link');
 
-		if (!$asset->store())
+		if (!$asset->store()) 
 		{
 			$this->setError($asset->getError());
 		}
@@ -180,21 +201,21 @@ class CollectionsControllerMedia extends \Hubzero\Component\SiteController
 
 	/**
 	 * Upload a file to the wiki via AJAX
-	 *
+	 * 
 	 * @return     string
 	 */
 	public function ajaxCreateTask()
 	{
 		// Check if they're logged in
-		if ($this->juser->get('guest'))
+		if ($this->juser->get('guest')) 
 		{
-			echo json_encode(array('error' => JText::_('COM_COLLECTIONS_ERROR_LOGIN_REQUIRED')));
+			echo json_encode(array('error' => JText::_('Must be logged in.')));
 			return;
 		}
 
 		// Ensure we have an ID to work with
 		$listdir = strtolower(JRequest::getVar('dir', ''));
-		if (!$listdir)
+		if (!$listdir) 
 		{
 			echo json_encode(array('error' => JText::_('COM_COLLECTIONS_NO_ID')));
 			return;
@@ -203,23 +224,19 @@ class CollectionsControllerMedia extends \Hubzero\Component\SiteController
 		if (substr($listdir, 0, 3) == 'tmp')
 		{
 			$item = new CollectionsModelItem($listdir);
-			if (!$item->exists())
+			$item->set('id', 0);
+			$item->set('state', 0);
+			$item->set('description', $listdir);
+			if (!$item->store())
 			{
-				$item->set('id', 0);
-				$item->set('state', 0);
-				$item->set('access', 0);
-				$item->set('title', $listdir);
-				if (!$item->store())
-				{
-					echo json_encode(array(
-						'success'   => false,
-						'errors'    => $item->getErrors(),
-						'file'      => 'http://',
-						'directory' => '',
-						'id'        => $listdir
-					));
-					return;
-				}
+				echo json_encode(array(
+					'success'   => false, 
+					'errors'    => $item->getErrors(),
+					'file'      => 'http://',
+					'directory' => '',
+					'id'        => $listdir
+				));
+				return;
 			}
 			$listdir = $item->get('id');
 		}
@@ -232,11 +249,11 @@ class CollectionsControllerMedia extends \Hubzero\Component\SiteController
 		$asset->set('state', 1);
 		$asset->set('type', 'link');
 
-		if (!$asset->store())
+		if (!$asset->store()) 
 		{
 			//$this->setError($asset->getError());
 			echo json_encode(array(
-				'success'   => false,
+				'success'   => false, 
 				'errors'    => $asset->getErrors(),
 				'file'      => 'http://',
 				'directory' => '',
@@ -247,7 +264,7 @@ class CollectionsControllerMedia extends \Hubzero\Component\SiteController
 
 		//echo result
 		echo json_encode(array(
-			'success'   => true,
+			'success'   => true, 
 			'file'      => 'http://',
 			'directory' => '',
 			'id'        => $listdir
@@ -256,21 +273,21 @@ class CollectionsControllerMedia extends \Hubzero\Component\SiteController
 
 	/**
 	 * Upload a file to the wiki via AJAX
-	 *
+	 * 
 	 * @return     string
 	 */
 	public function ajaxUploadTask()
 	{
 		// Check if they're logged in
-		if ($this->juser->get('guest'))
+		if ($this->juser->get('guest')) 
 		{
-			echo json_encode(array('error' => JText::_('COM_COLLECTIONS_ERROR_LOGIN_REQUIRED')));
+			echo json_encode(array('error' => JText::_('Must be logged in.')));
 			return;
 		}
 
 		// Ensure we have an ID to work with
 		$listdir = strtolower(JRequest::getVar('dir', ''));
-		if (!$listdir)
+		if (!$listdir) 
 		{
 			echo json_encode(array('error' => JText::_('COM_COLLECTIONS_NO_ID')));
 			return;
@@ -278,23 +295,22 @@ class CollectionsControllerMedia extends \Hubzero\Component\SiteController
 
 		if (substr($listdir, 0, 3) == 'tmp')
 		{
-			$item = new CollectionsModelItem($listdir);
-			if (!$item->exists())
+			$item = new CollectionsModelItem();
+			$item->set('state', 0);
+			$item->set('description', $listdir);
+			if (!$item->store())
 			{
-				$item->set('state', 0);
-				$item->set('access', 0);
-				$item->set('title', $listdir);
-				if (!$item->store())
-				{
-					echo json_encode(array(
-						'error' => $item->getError()
-					));
-					return;
-				}
+				echo json_encode(array(
+					'error' => $item->getError()
+				));
+				return;
 			}
 			$listdir = $item->get('id');
 		}
 
+		//allowed extensions for uplaod
+		//$allowedExtensions = array("png","jpeg","jpg","gif");
+
 		//max upload size
 		$sizeLimit = $this->config->get('maxAllowed', 40000000);
 
@@ -307,44 +323,47 @@ class CollectionsControllerMedia extends \Hubzero\Component\SiteController
 		}
 		elseif (isset($_FILES['qqfile']))
 		{
+			//$files = JRequest::getVar('qqfile', '', 'files', 'array');
+			
 			$stream = false;
 			$file = $_FILES['qqfile']['name'];
 			$size = (int) $_FILES['qqfile']['size'];
 		}
 		else
 		{
-			echo json_encode(array('error' => JText::_('COM_COLLECTIONS_FILE_NOT_FOUND')));
+			echo json_encode(array('error' => JText::_('File not found')));
 			return;
 		}
 
 		//define upload directory and make sure its writable
 		$path = JPATH_ROOT . DS . trim($this->config->get('filepath', '/site/collections'), DS) . DS . $listdir;
-		if (!is_dir($path))
+		if (!is_dir($path)) 
 		{
 			jimport('joomla.filesystem.folder');
-			if (!JFolder::create($path))
+			if (!JFolder::create($path, 0777)) 
 			{
-				echo json_encode(array('error' => JText::_('COM_COLLECTIONS_ERROR_UNABLE_TO_CREATE_UPLOAD_DIR')));
+				echo json_encode(array('error' => JText::_('Error uploading. Unable to create path.')));
 				return;
 			}
 		}
 
 		if (!is_writable($path))
 		{
-			echo json_encode(array('error' => JText::_('COM_COLLECTIONS_ERROR_UPLOAD_DIR_NOT_WRITABLE')));
+			echo json_encode(array('error' => JText::_('Server error. Upload directory isn\'t writable.')));
 			return;
 		}
 
 		//check to make sure we have a file and its not too big
-		if ($size == 0)
+		if ($size == 0) 
 		{
-			echo json_encode(array('error' => JText::_('COM_COLLECTIONS_ERROR_EMPTY_FILE')));
+			echo json_encode(array('error' => JText::_('File is empty')));
 			return;
 		}
-		if ($size > $sizeLimit)
+		if ($size > $sizeLimit) 
 		{
-			$max = preg_replace('/<abbr \w+=\\"\w+\\">(\w{1,3})<\\/abbr>/', '$1', \Hubzero\Utility\Number::formatBytes($sizeLimit));
-			echo json_encode(array('error' => JText::sprintf('COM_COLLECTIONS_ERROR_FILE_TOO_LARGE', $max)));
+			ximport('Hubzero_View_Helper_Html');
+			$max = preg_replace('/<abbr \w+=\\"\w+\\">(\w{1,3})<\\/abbr>/', '$1', Hubzero_View_Helper_Html::formatSize($sizeLimit));
+			echo json_encode(array('error' => JText::sprintf('File is too large. Max file upload size is %s', $max)));
 			return;
 		}
 
@@ -359,7 +378,7 @@ class CollectionsControllerMedia extends \Hubzero\Component\SiteController
 		$filename = str_replace(' ', '_', $filename);
 
 		$ext = $pathinfo['extension'];
-		while (file_exists($path . DS . $filename . '.' . $ext))
+		while (file_exists($path . DS . $filename . '.' . $ext)) 
 		{
 			$filename .= rand(10, 99);
 		}
@@ -389,20 +408,11 @@ class CollectionsControllerMedia extends \Hubzero\Component\SiteController
 		$asset = new CollectionsModelAsset();
 		$asset->set('item_id', intval($listdir));
 		$asset->set('filename', $filename . '.' . $ext);
-		if ($asset->image())
-		{
-			$hi = new \Hubzero\Image\Processor($file);
-			if (count($hi->getErrors()) == 0)
-			{
-				$hi->autoRotate();
-				$hi->save();
-			}
-		}
 		$asset->set('description', JRequest::getVar('description', '', 'post'));
 		$asset->set('state', 1);
 		$asset->set('type', 'file');
 
-		if (!$asset->store())
+		if (!$asset->store()) 
 		{
 			echo json_encode(array(
 				'error' => $asset->getError()
@@ -410,35 +420,24 @@ class CollectionsControllerMedia extends \Hubzero\Component\SiteController
 			return;
 		}
 
-		$view = new \Hubzero\Component\View(array(
-			'name'   => 'media',
-			'layout' => '_asset'
-		));
-		$view->i          = JRequest::getInt('i', 0);
-		$view->option     = $this->_option;
-		$view->controller = $this->_controller;
-		$view->asset      = $asset;
-		$view->no_html    = 1;
-
 		//echo result
 		echo json_encode(array(
-			'success'   => true,
+			'success'   => true, 
 			'file'      => $filename . '.' . $ext,
 			'directory' => str_replace(JPATH_ROOT, '', $path),
-			'id'        => $listdir,
-			'html'      => str_replace('>', '&gt;',  $view->loadTemplate()) // Entities have to be encoded or IE 8 goes nuts
+			'id'        => $listdir
 		));
 	}
 
 	/**
 	 * Upload a file to the wiki
-	 *
+	 * 
 	 * @return     void
 	 */
 	public function uploadTask()
 	{
 		// Check if they're logged in
-		if ($this->juser->get('guest'))
+		if ($this->juser->get('guest')) 
 		{
 			$this->displayTask();
 			return;
@@ -451,7 +450,7 @@ class CollectionsControllerMedia extends \Hubzero\Component\SiteController
 
 		// Ensure we have an ID to work with
 		$listdir = JRequest::getInt('dir', 0, 'post');
-		if (!$listdir)
+		if (!$listdir) 
 		{
 			$this->setError(JText::_('COM_COLLECTIONS_NO_ID'));
 			$this->displayTask();
@@ -460,7 +459,7 @@ class CollectionsControllerMedia extends \Hubzero\Component\SiteController
 
 		// Incoming file
 		$file = JRequest::getVar('upload', '', 'files', 'array');
-		if (!$file['name'])
+		if (!$file['name']) 
 		{
 			$this->setError(JText::_('COM_COLLECTIONS_NO_FILE'));
 			$this->displayTask();
@@ -470,12 +469,12 @@ class CollectionsControllerMedia extends \Hubzero\Component\SiteController
 		// Build the upload path if it doesn't exist
 		$path = JPATH_ROOT . DS . trim($this->config->get('filepath', '/site/collections'), DS) . DS . $listdir;
 
-		if (!is_dir($path))
+		if (!is_dir($path)) 
 		{
 			jimport('joomla.filesystem.folder');
-			if (!JFolder::create($path))
+			if (!JFolder::create($path, 0777)) 
 			{
-				$this->setError(JText::_('COM_COLLECTIONS_ERROR_UNABLE_TO_CREATE_UPLOAD_DIR'));
+				$this->setError(JText::_('Error uploading. Unable to create path.'));
 				$this->displayTask();
 				return;
 			}
@@ -488,31 +487,22 @@ class CollectionsControllerMedia extends \Hubzero\Component\SiteController
 		$file['name'] = str_replace(' ', '_', $file['name']);
 
 		// Upload new files
-		if (!JFile::upload($file['tmp_name'], $path . DS . $file['name']))
+		if (!JFile::upload($file['tmp_name'], $path . DS . $file['name'])) 
 		{
-			$this->setError(JText::_('COM_COLLECTIONS_ERROR_UNABLE_TO_UPLOAD'));
+			$this->setError(JText::_('ERROR_UPLOADING'));
 		}
-		// File was uploaded
-		else
+		// File was uploaded 
+		else 
 		{
 			// Create database entry
 			$asset = new CollectionsModelAsset();
 			$asset->set('item_id', intval($listdir));
 			$asset->set('filename', $file['name']);
-			if ($asset->image())
-			{
-				$hi = new \Hubzero\Image\Processor($path . DS . $file['name']);
-				if (count($hi->getErrors()) == 0)
-				{
-					$hi->autoRotate();
-					$hi->save();
-				}
-			}
 			$asset->set('description', JRequest::getVar('description', '', 'post'));
 			$asset->set('state', 1);
 			$asset->set('type', 'file');
 
-			if (!$asset->store())
+			if (!$asset->store()) 
 			{
 				$this->setError($asset->getError());
 			}
@@ -524,7 +514,7 @@ class CollectionsControllerMedia extends \Hubzero\Component\SiteController
 
 	/**
 	 * Delete a file in the wiki
-	 *
+	 * 
 	 * @return     void
 	 */
 	public function deleteTask()
@@ -535,12 +525,21 @@ class CollectionsControllerMedia extends \Hubzero\Component\SiteController
 		}
 
 		// Check if they're logged in
-		if ($this->juser->get('guest'))
+		if ($this->juser->get('guest')) 
 		{
 			$this->displayTask();
 			return;
 		}
 
+		// Incoming
+		$listdir = JRequest::getInt('dir', 0, 'get');
+		if (!$listdir) 
+		{
+			$this->setError(JText::_('COM_COLLECTIONS_NO_ID'));
+			$this->displayTask();
+			return;
+		}
+
 		// Incoming asset
 		$id = JRequest::getInt('asset', 0, 'get');
 
@@ -548,8 +547,7 @@ class CollectionsControllerMedia extends \Hubzero\Component\SiteController
 
 		if ($model->exists())
 		{
-			$model->set('state', 2);
-			if (!$model->store())
+			if (!$model->remove())
 			{
 				$this->setError($model->getError());
 			}
@@ -561,13 +559,13 @@ class CollectionsControllerMedia extends \Hubzero\Component\SiteController
 
 	/**
 	 * Display a form for uploading files
-	 *
+	 * 
 	 * @return     void
 	 */
 	public function ajaxDeleteTask()
 	{
 		// Incoming
-		$id = JRequest::getInt('asset', 0);
+		$id = JRequest::getInt('id', 0);
 
 		if ($id)
 		{
@@ -575,28 +573,28 @@ class CollectionsControllerMedia extends \Hubzero\Component\SiteController
 
 			if ($model->exists())
 			{
-				$model->set('state', 2);
-				if (!$model->store())
+				if (!$model->remove())
 				{
 					echo json_encode(array(
 						'success' => false,
 						'error'   => $model->getError()
 					));
 					return;
+					//$this->setError($model->getError());
 				}
 			}
 		}
 
 		//echo result
 		echo json_encode(array(
-			'success' => true,
+			'success' => true, 
 			'asset'   => $id
 		));
 	}
 
 	/**
 	 * Display a form for uploading files
-	 *
+	 * 
 	 * @return     void
 	 */
 	public function displayTask()
@@ -609,7 +607,7 @@ class CollectionsControllerMedia extends \Hubzero\Component\SiteController
 		// Output HTML
 		$this->view->config = $this->config;
 
-		if ($this->getError())
+		if ($this->getError()) 
 		{
 			foreach ($this->getErrors() as $error)
 			{
@@ -622,7 +620,7 @@ class CollectionsControllerMedia extends \Hubzero\Component\SiteController
 
 	/**
 	 * Display a list of files
-	 *
+	 * 
 	 * @return     void
 	 */
 	public function listTask()
@@ -630,12 +628,12 @@ class CollectionsControllerMedia extends \Hubzero\Component\SiteController
 		// Incoming
 		$listdir = JRequest::getInt('dir', 0, 'get');
 
-		if (!$listdir)
+		if (!$listdir) 
 		{
 			$this->setError(JText::_('COM_COLLECTIONS_NO_ID'));
 		}
 
-		$this->view->item = CollectionsModelItem::getInstance($listdir);
+		$this->view->item    = CollectionsModelItem::getInstance($listdir);
 		if (!$this->view->item->exists())
 		{
 			$this->setError(JText::_('COM_COLLECTIONS_NO_ID'));
@@ -644,7 +642,9 @@ class CollectionsControllerMedia extends \Hubzero\Component\SiteController
 		$this->view->config  = $this->config;
 		$this->view->listdir = $listdir;
 
-		if ($this->getError())
+		$this->_getStyles();
+
+		if ($this->getError()) 
 		{
 			foreach ($this->getErrors() as $error)
 			{
