@@ -362,7 +362,8 @@ ximport('Hubzero_User_Profile_Helper');
 			<input type="hidden" name="fields[parent]" value="<?php echo $this->post->id; ?>" />
 			<input type="hidden" name="fields[state]" value="1" />
 			<input type="hidden" name="fields[id]" value="" />
-			<input type="hidden" name="fields[group_id]" value="0" />
+			<input type="hidden" name="fields[scope]" value="site" />
+			<input type="hidden" name="fields[scope_id]" value="0" />
 	
 			<input type="hidden" name="option" value="<?php echo $this->option; ?>" />
 			<input type="hidden" name="controller" value="threads" />
