@@ -31,14 +31,14 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die('Restricted access');
 
-$pathway = JFactory::getApplication()->getPathway();
+$pathway =& JFactory::getApplication()->getPathway();
 $pathway->addItem(
-	JText::_('COM_WIKI_SPECIAL_RECENT_CHANGES'),
-	$this->page->link()
+	JText::_('New Pages'),
+	'index.php?option=' . $this->option . '&scope=' . $this->page->scope . '&pagename=Special:RecentChanges'
 );
 
-$jconfig = JFactory::getConfig();
-$juser = JFactory::getUser();
+$jconfig =& JFactory::getConfig();
+$juser =& JFactory::getUser();
 
 $dir = strtoupper(JRequest::getVar('dir', 'DESC'));
 if (!in_array($dir, array('ASC', 'DESC')))
@@ -49,28 +49,28 @@ if (!in_array($dir, array('ASC', 'DESC')))
 $limit = JRequest::getInt('limit', $jconfig->getValue('config.list_limit'));
 $start = JRequest::getInt('limitstart', 0);
 
-$database = JFactory::getDBO();
+$database =& JFactory::getDBO();
 
-$query = "SELECT COUNT(*)
-			FROM `#__wiki_version` AS wv
-			INNER JOIN `#__wiki_page` AS wp
-				ON wp.id = wv.pageid
-			WHERE wv.approved = 1
-				" . ($this->page->get('scope') ? "AND wp.scope LIKE " . $database->quote($this->page->get('scope') . '%') . " " : "AND (wp.scope='' OR wp.scope IS NULL) ") . "
+$query = "SELECT COUNT(*) 
+			FROM #__wiki_version AS wv 
+			INNER JOIN #__wiki_page AS wp 
+				ON wp.id = wv.pageid 
+			WHERE wv.approved = 1 
+				AND wp.scope = '{$this->page->scope}' 
 				AND wp.state < 2
-				AND wp.access != 2";
+				AND wp.access != 1";
 
 $database->setQuery($query);
 $total = $database->loadResult();
 
-$query = "SELECT wv.pageid, wp.title, wp.pagename, wp.scope, wp.group_cn, wp.access, wv.version, wv.created_by, wv.created, wv.summary
-			FROM `#__wiki_version` AS wv
-			INNER JOIN `#__wiki_page` AS wp
-				ON wp.id = wv.pageid
-			WHERE wv.approved = 1
-				" . ($this->page->get('scope') ? "AND wp.scope LIKE " . $database->quote($this->page->get('scope') . '%') . " " : "AND (wp.scope='' OR wp.scope IS NULL) ") . "
+$query = "SELECT wv.pageid, wp.title, wp.pagename, wp.scope, wp.group_cn, wp.access, wv.version, wv.created_by, wv.created, wv.summary 
+			FROM #__wiki_version AS wv 
+			INNER JOIN #__wiki_page AS wp 
+				ON wp.id = wv.pageid 
+			WHERE wv.approved = 1 
+				AND wp.scope = '{$this->page->scope}' 
 				AND wp.state < 2
-				AND wp.access != 2
+				AND wp.access != 1 
 			ORDER BY created DESC";
 if ($limit && $limit != 'all')
 {
@@ -80,56 +80,72 @@ if ($limit && $limit != 'all')
 $database->setQuery($query);
 $rows = $database->loadObjectList();
 
+jimport('joomla.html.pagination');
+$pageNav = new JPagination(
+	$total, 
+	$start, 
+	$limit
+);
+
 $altdir = ($dir == 'ASC') ? 'DESC' : 'ASC';
 ?>
-<form method="get" action="<?php echo JRoute::_($this->page->link()); ?>">
+<form method="get" action="<?php echo JRoute::_('index.php?option=' . $this->option . '&scope=' . $this->page->scope . '&pagename=Special:RecentChanges'); ?>">
 	<p>
-		<?php echo JText::_('COM_WIKI_SPECIAL_RECENT_CHANGES_ABOUT'); ?>
+		This special page shows all the recent changes in this wiki. The most recent changes are shown at top of the list.
 	</p>
 	<div class="container">
 		<table class="file entries">
 			<thead>
 				<tr>
 					<th scope="col">
-						<?php echo JText::_('COM_WIKI_COL_DIFF'); ?>
+						<?php echo JText::_('Diff'); ?>
 					</th>
 					<th scope="col">
-						<?php echo JText::_('COM_WIKI_COL_DATE'); ?>
+						<?php echo JText::_('Date'); ?>
 					</th>
 					<th scope="col">
-						<?php echo JText::_('COM_WIKI_COL_TITLE'); ?>
+						<?php echo JText::_('Title'); ?>
 					</th>
 					<th scope="col">
-						<?php echo JText::_('COM_WIKI_COL_CREATOR'); ?>
+						<?php echo JText::_('Created by'); ?>
 					</th>
 					<th scope="col">
-						<?php echo JText::_('COM_WIKI_COL_EDIT_SUMMARY'); ?>
+						<?php echo JText::_('Edit summary'); ?>
 					</th>
 				</tr>
 			</thead>
 			<tbody>
-			<?php
-			if ($rows)
-			{
-				foreach ($rows as $row)
-				{
-					$name = JText::_('(unknown)');
-					$xprofile = \Hubzero\User\Profile::getInstance($row->created_by);
-					if (is_object($xprofile))
-					{
-						$name = $this->escape(stripslashes($xprofile->get('name')));
-						$name = ($xprofile->get('public') ? '<a href="' . JRoute::_($xprofile->getLink()) . '">' . $name . '</a>' : $name);
-					}
-			?>
+<?php
+if ($rows) 
+{
+	ximport('Hubzero_User_Profile');
+
+	$dateFormat = '%d %b %Y';
+	$tz = 0;
+	if (version_compare(JVERSION, '1.6', 'ge'))
+	{
+		$dateFormat = 'd M Y';
+		$tz = true;
+	}
+
+	foreach ($rows as $row)
+	{
+		$name = JText::_('(unknown)');
+		$xprofile = Hubzero_User_Profile::getInstance($row->created_by);
+		if (is_object($xprofile))
+		{
+			$name = '<a href="' . JRoute::_('index.php?option=com_members&id=' . $row->created_by) . '">' . $this->escape(stripslashes($xprofile->get('name'))) . '</a>';
+		}
+?>
 				<tr>
 					<td>
 						(
 						<?php if ($row->version > 1) { ?>
-							<a href="<?php echo JRoute::_('index.php?option=' . $this->option . '&scope=' . $row->scope . '&pagename=' . $row->pagename . '&task=compare&oldid=' . ($row->version - 1). '&diff=' . $row->version); ?>"><?php echo JText::_('COM_WIKI_DIFF'); ?></a> |
+							<a href="<?php echo JRoute::_('index.php?option=' . $this->option . '&scope=' . $row->scope . '&pagename=' . $row->pagename . '&task=compare&oldid=' . ($row->version - 1). '&diff=' . $row->version); ?>">diff</a> | 
 						<?php } else { ?>
-							<?php echo JText::_('COM_WIKI_DIFF'); ?> |
+							diff | 
 						<?php } ?>
-							<a href="<?php echo JRoute::_('index.php?option=' . $this->option . '&scope=' . $row->scope . '&pagename=' . $row->pagename . '&task=history'); ?>"><?php echo JText::_('COM_WIKI_HIST'); ?></a>
+							<a href="<?php echo JRoute::_('index.php?option=' . $this->option . '&scope=' . $row->scope . '&pagename=' . $row->pagename . '&task=history'); ?>">hist</a>
 						)
 					</td>
 					<td>
@@ -147,34 +163,28 @@ $altdir = ($dir == 'ASC') ? 'DESC' : 'ASC';
 						<span><?php echo $this->escape(stripslashes($row->summary)); ?></span>
 					</td>
 				</tr>
-			<?php
-				}
-			}
-			else
-			{
-			?>
+<?php
+	}
+}
+else
+{
+?>
 				<tr>
-					<td colspan="5">
-						<?php echo JText::_('COM_WIKI_NONE'); ?>
+					<td colspan="4">
+						<?php echo JText::_('No pages found.'); ?>
 					</td>
 				</tr>
-			<?php
-			}
-			?>
+<?php
+}
+?>
 			</tbody>
 		</table>
-		<?php
-		jimport('joomla.html.pagination');
-		$pageNav = new JPagination(
-			$total,
-			$start,
-			$limit
-		);
-		$pageNav->setAdditionalUrlParam('scope', $this->page->get('scope'));
-		$pageNav->setAdditionalUrlParam('pagename', $this->page->get('pagename'));
+<?php
+$pageNav->setAdditionalUrlParam('scope', $this->page->scope);
+$pageNav->setAdditionalUrlParam('pagename', $this->page->pagename);
 
-		echo $pageNav->getListFooter();
-		?>
+echo $pageNav->getListFooter();
+?>
 		<div class="clearfix"></div>
 	</div>
 </form>
\ No newline at end of file
