@@ -75,17 +75,17 @@ class Hubzero_Document
 		if (file_exists(JPATH_SITE . $templatecss)) 
 		{
 			// Chech for CSS in /templates/$template/html/$component/
-			$jdocument->addStyleSheet(rtrim(JURI::getInstance()->base(true), DS) . $templatecss . '?v=' . filemtime(JPATH_SITE . $templatecss), $type, $media, $attribs);
+			$jdocument->addStyleSheet($templatecss . '?v=' . filemtime(JPATH_SITE . $templatecss), $type, $media, $attribs);
 		}
 		else if (file_exists(JPATH_SITE . $assetcss)) 
 		{
 			// Chech for CSS in /components/$component/assets/css/
-			$jdocument->addStyleSheet(rtrim(JURI::getInstance()->base(true), DS) . $assetcss . '?v=' . filemtime(JPATH_SITE . $assetcss), $type, $media, $attribs);
+			$jdocument->addStyleSheet($assetcss . '?v=' . filemtime(JPATH_SITE . $assetcss), $type, $media, $attribs);
 		} 
 		else if (file_exists(JPATH_SITE . $componentcss)) 
 		{
 			// Chech for CSS in /components/$component/
-			$jdocument->addStyleSheet(rtrim(JURI::getInstance()->base(true), DS) . $componentcss . '?v=' . filemtime(JPATH_SITE . $componentcss), $type, $media, $attribs);
+			$jdocument->addStyleSheet($componentcss . '?v=' . filemtime(JPATH_SITE . $componentcss), $type, $media, $attribs);
 		}
 	}
 
@@ -126,11 +126,11 @@ class Hubzero_Document
 
 		if ($urlAlt && file_exists(JPATH_SITE . $urlAlt)) 
 		{
-			$jdocument->addScript(rtrim(JURI::getInstance()->base(true), DS) . $urlAlt . '?v=' . filemtime(JPATH_SITE . $urlAlt), $type, $defer, $async);
+			$jdocument->addScript($urlAlt . '?v=' . filemtime(JPATH_SITE . $urlAlt), $type, $defer, $async);
 		} 
 		else if (file_exists(JPATH_SITE . $url)) 
 		{
-			$jdocument->addScript(rtrim(JURI::getInstance()->base(true), DS) . $url . '?v=' . filemtime(JPATH_SITE . $url), $type, $defer, $async);
+			$jdocument->addScript($url . '?v=' . filemtime(JPATH_SITE . $url), $type, $defer, $async);
 		}
 	}
 
@@ -162,11 +162,11 @@ class Hubzero_Document
 
 		if (file_exists(JPATH_SITE . $templatecss)) 
 		{
-			$jdocument->addStyleSheet(rtrim(JURI::getInstance()->base(true), DS) . $templatecss . '?v=' . filemtime(JPATH_SITE . $templatecss), $type, $media, $attribs);
+			$jdocument->addStyleSheet($templatecss . '?v=' . filemtime(JPATH_SITE . $templatecss), $type, $media, $attribs);
 		} 
 		else 
 		{
-			$jdocument->addStyleSheet(rtrim(JURI::getInstance()->base(true), DS) . $systemcss . '?v=' . filemtime(JPATH_SITE . $systemcss), $type, $media, $attribs);
+			$jdocument->addStyleSheet($systemcss . '?v=' . filemtime(JPATH_SITE . $systemcss), $type, $media, $attribs);
 		}
 	}
 
@@ -206,11 +206,11 @@ class Hubzero_Document
 
 		if ($urlAlt && file_exists(JPATH_SITE . $urlAlt)) 
 		{
-			$jdocument->addScript(rtrim(JURI::getInstance()->base(true), DS) . $urlAlt . '?v=' . filemtime(JPATH_SITE . $urlAlt), $type, $defer, $async);
+			$jdocument->addScript($urlAlt . '?v=' . filemtime(JPATH_SITE . $urlAlt), $type, $defer, $async);
 		} 
 		else if (file_exists(JPATH_SITE . $url)) 
 		{
-			$jdocument->addScript(rtrim(JURI::getInstance()->base(true), DS) . $url . '?v=' . filemtime(JPATH_SITE . $url), $type, $defer, $async);
+			$jdocument->addScript($url . '?v=' . filemtime(JPATH_SITE . $url), $type, $defer, $async);
 		}
 	}
 
@@ -236,15 +236,15 @@ class Hubzero_Document
 
 		if (file_exists(JPATH_SITE . $templateimage)) 
 		{
-			return rtrim(JURI::getInstance()->base(true), DS) . $templateimage;
+			return $templateimage;
 		} 
 		else if (file_exists(JPATH_SITE . $assetimage)) 
 		{
-			return rtrim(JURI::getInstance()->base(true), DS) . $assetimage;
+			return $assetimage;
 		}
 		else 
 		{
-			return rtrim(JURI::getInstance()->base(true), DS) . $componentimage;
+			return $componentimage;
 		}
 	}
 
@@ -262,7 +262,7 @@ class Hubzero_Document
 
 		$template  = $mainframe->getTemplate();
 
-		$templatecss = DS . 'templates' . DS . $template . DS . 'html' . DS . $component . DS . $stylesheet;
+		$templatecss = DS . 'templates' . DS . $template . DS . 'html' . DS . $component . DS . 'css' . DS . $stylesheet;
 
 		$assetcss = DS . 'components' . DS . $component . DS . 'assets' . DS . 'css' . DS . $stylesheet;
 
@@ -270,15 +270,15 @@ class Hubzero_Document
 
 		if (file_exists(JPATH_SITE . $templatecss)) 
 		{
-			return rtrim(JURI::getInstance()->base(true), DS) . $templatecss;
+			return $templatecss;
 		} 
 		else if (file_exists(JPATH_SITE . $assetcss)) 
 		{
-			return rtrim(JURI::getInstance()->base(true), DS) . $assetcss;
+			return $assetcss;
 		}
 		else 
 		{
-			return rtrim(JURI::getInstance()->base(true), DS) . $componentcss;
+			return $componentcss;
 		}
 	}
 
@@ -302,11 +302,11 @@ class Hubzero_Document
 
 		if (file_exists(JPATH_SITE . $templateimage)) 
 		{
-			return rtrim(JURI::getInstance()->base(true), DS) . $templateimage;
+			return $templateimage;
 		} 
 		else 
 		{
-			return rtrim(JURI::getInstance()->base(true), DS) . $moduleimage;
+			return $moduleimage;
 		}
 	}
 
@@ -339,11 +339,11 @@ class Hubzero_Document
 
 		if (file_exists(JPATH_SITE . $templatecss)) 
 		{
-			$jdocument->addStyleSheet(rtrim(JURI::getInstance()->base(true), DS) . $templatecss . '?v=' . filemtime(JPATH_SITE . $templatecss), $type, $media, $attribs);
+			$jdocument->addStyleSheet($templatecss . '?v=' . filemtime(JPATH_SITE . $templatecss), $type, $media, $attribs);
 		} 
 		else 
 		{
-			$jdocument->addStyleSheet(rtrim(JURI::getInstance()->base(true), DS) . $modulecss . '?v=' . filemtime(JPATH_SITE . $modulecss), $type, $media, $attribs);
+			$jdocument->addStyleSheet($modulecss . '?v=' . filemtime(JPATH_SITE . $modulecss), $type, $media, $attribs);
 		}
 	}
 	
@@ -379,11 +379,11 @@ class Hubzero_Document
 
 		if ($urlAlt && file_exists(JPATH_SITE . $urlAlt)) 
 		{
-			$jdocument->addScript(rtrim(JURI::getInstance()->base(true), DS) . $urlAlt . '?v=' . filemtime(JPATH_SITE . $urlAlt), $type, $defer, $async);
+			$jdocument->addScript($urlAlt . '?v=' . filemtime(JPATH_SITE . $urlAlt), $type, $defer, $async);
 		} 
 		else 
 		{
-			$jdocument->addScript(rtrim(JURI::getInstance()->base(true), DS) . $url . '?v=' . filemtime(JPATH_SITE . $url), $type, $defer, $async);
+			$jdocument->addScript($url . '?v=' . filemtime(JPATH_SITE . $url), $type, $defer, $async);
 		}
 	}
 
@@ -416,11 +416,11 @@ class Hubzero_Document
 
 		if (file_exists(JPATH_SITE . $templatecss)) 
 		{
-			$jdocument->addStyleSheet(rtrim(JURI::getInstance()->base(true), DS) . $templatecss . '?v=' . filemtime(JPATH_SITE . $templatecss), $type, $media, $attribs);
+			$jdocument->addStyleSheet($templatecss . '?v=' . filemtime(JPATH_SITE . $templatecss), $type, $media, $attribs);
 		} 
-		else if (file_exists(JPATH_SITE . $plugincss))
+		else 
 		{
-			$jdocument->addStyleSheet(rtrim(JURI::getInstance()->base(true), DS) . $plugincss . '?v=' . filemtime(JPATH_SITE . $plugincss), $type, $media, $attribs);
+			$jdocument->addStyleSheet($plugincss . '?v=' . filemtime(JPATH_SITE . $plugincss), $type, $media, $attribs);
 		}
 	}
 	
@@ -457,11 +457,11 @@ class Hubzero_Document
 
 		if ($urlAlt && file_exists(JPATH_SITE . $urlAlt)) 
 		{
-			$jdocument->addScript(rtrim(JURI::getInstance()->base(true), DS) . $urlAlt . '?v=' . filemtime(JPATH_SITE . $urlAlt), $type, $defer, $async);
+			$jdocument->addScript($urlAlt . '?v=' . filemtime(JPATH_SITE . $urlAlt), $type, $defer, $async);
 		} 
-		else if (file_exists(JPATH_SITE . $url)) 
+		else 
 		{
-			$jdocument->addScript(rtrim(JURI::getInstance()->base(true), DS) . $url . '?v=' . filemtime(JPATH_SITE . $url), $type, $defer, $async);
+			$jdocument->addScript($url . '?v=' . filemtime(JPATH_SITE . $url), $type, $defer, $async);
 		}
 	}
 
@@ -475,183 +475,103 @@ class Hubzero_Document
 	 */
 	public static function getSystemStylesheet($elements = null)
 	{
+		// Anything passed?
+		if (!$elements)
+		{
+			return '';
+		}
+		// Is it a string?
+		if (is_string($elements))
+		{
+			$elements = explode(',', $elements);
+		}
+		if (count($elements) <= 0)
+		{
+			return '';
+		}
+		// Trim items
+		$elements = array_map('trim', $elements);
+
 		// Path to system cache
 		$cachedir = JPATH_ROOT . DS . 'cache';
 		// Path to system CSS
 		$thispath = JPATH_ROOT . DS . 'media' . DS . 'system' . DS . 'css';
 
-		try {
-			// Primary build file
-			$primary   = 'site';
+		// Determine last modification date of the files
+		$lastmodified = 0;
 
-			// Cache vars
-			$output    = $cachedir . DS . $primary . '.css';
-
-			// If debugging is turned off and a cache file exist
-			//if (!JDEBUG && file_exists($output))
-			if (JFactory::getConfig()->getValue('config.application_env', 'production') == 'production' && file_exists($output))
-			{
-				$output =  DS . 'cache' . DS . $primary. '.css?v=' . filemtime($output);
-			}
-			else
-			{
-				$lesspath = JPATH_ROOT . DS . 'media' . DS . 'system' . DS . 'less';
-
-				// Try to compile LESS files
-				$less = new lessc;
-				$less->setFormatter('compressed');
-
-				// Are there any template overrides?
-				$template  = JPATH_ROOT . DS . 'templates' . DS . JFactory::getApplication()->getTemplate() . DS . 'less'; // . 'bootstrap.less';
-				$input     = $lesspath . DS . $primary . '.less';
-
-				if (file_exists($template . DS . $primary . '.less')) 
-				{
-					// Reset the path to the primary build file
-					$input = $template . DS . $primary . '.less';
-				}
-
-				// Add the template path to the import list
-				$less->setImportDir(array(
-					$template . DS, 
-					$lesspath . DS
-				));
-
-				$cacheFile = $cachedir . DS . $primary . '.less.cache';
-				$cache     = null;
-
-				if (file_exists($cacheFile)) 
-				{
-					$cache = unserialize(file_get_contents($cacheFile));
-				}
-
-				// If no cache file or the root build file is different
-				if (!$cache || ($cache['root'] != $input))
-				{
-					$cache = $input;
-				}
-
-				// create a new cache object, and compile
-				/*
-				array(
-					'files'    => list of files imported,
-					'root'     => root file (bootstrap.less)
-					'updated'  => timestamp,
-					'compiled' => compiled LESS
-				)
-				*/
-
-				$newCache = $less->cachedCompile($cache);
-
-				// Did the cache change?
-				if (!is_array($cache) || $newCache['updated'] > $cache['updated']) 
-				{
-					file_put_contents($cacheFile, serialize($newCache));  // Update the compiled LESS timestamp
-					file_put_contents($output, $newCache['compiled']);    // Update the compiled LESS
-				}
-				$output =  DS . 'cache' . DS . $primary . '.css?v=' . $newCache['updated'];
-			}
-		} 
-		catch (exception $e) 
+		foreach ($elements as $k => $element) 
 		{
-			//echo "fatal error: " . $e->getMessage(); die();
+			if (!$element) 
+			{
+				$elements[$k] = false;
+				continue;
+			}
 
-			// Anything passed?
-			if (!$elements)
-			{
-				return '';
-			}
-			// Is it a string?
-			if (is_string($elements))
-			{
-				$elements = explode(',', $elements);
-			}
-			if (count($elements) <= 0)
-			{
-				return '';
-			}
-			// Trim items
-			$elements = array_map('trim', $elements);
+			// Strip file extension to normalize data
+			$element = basename($element, '.css');
 
-			// Determine last modification date of the files
-			$lastmodified = 0;
+			$elements[$k] = $element;
+
+			// Check if the file exists
+			$path = $thispath . DS . $element . '.css';
+
+			if (!file_exists($path)) 
+			{
+				$elements[$k] = false;
+				continue;
+			}
+
+			// Get the last modified time
+			// We take the max time so $lastmodified should be different if any of the files have changed.
+			$lastmodified += filemtime($path);
+		}
+
+		// Remove any empty items
+		$elements = array_filter($elements);
+
+		// Build hash
+		$hash = $lastmodified; // . '-' . md5(implode(',', $elements));
+
+		// Only one stylesheet called for so return it as is
+		if (count($elements) == 1)
+		{
+			return $thispath . DS . $elements[0] . '.css';
+		}
+
+		// Try the cache first to see if the combined files were already generated
+		$cachefile = 'system-' . $hash . '.css';
+
+		if (!file_exists($cachedir . DS . $cachefile)) 
+		{
+			$contents = '';
+			reset($elements);
 
 			foreach ($elements as $k => $element) 
 			{
-				if (!$element) 
-				{
-					$elements[$k] = false;
-					continue;
-				}
-
-				// Strip file extension to normalize data
-				$element = basename($element, '.css');
-
-				$elements[$k] = $element;
-
-				// Check if the file exists
-				$path = $thispath . DS . $element . '.css';
-
-				if (!file_exists($path)) 
-				{
-					$elements[$k] = false;
-					continue;
-				}
-
-				// Get the last modified time
-				// We take the max time so $lastmodified should be different if any of the files have changed.
-				$lastmodified += filemtime($path);
+				$contents .= "\n\n" . file_get_contents($thispath . DS . $element . '.css');
 			}
+			$patterns = array(
+				'!/\*[^*]*\*+([^/][^*]*\*+)*/!',  /* remove comments */
+				'/[\n\r \t]/',                    /* remove tabs, spaces, newlines, etc. */
+				'/ +/'                           /* collapse multiple spaces to a single space */
+				/* '/ ?([,:;{}]) ?/'                 remove space before and after , : ; { }     [!] apparently, IE 7 doesn't like this and won't process the stylesheet */
+			);
+			$replacements = array(
+				'',
+				' ',
+				' '/*,
+				'$1'*/
+			);
+			$contents = preg_replace($patterns, $replacements, $contents);
 
-			// Remove any empty items
-			$elements = array_filter($elements);
-
-			// Build hash
-			$hash = $lastmodified; // . '-' . md5(implode(',', $elements));
-
-			// Only one stylesheet called for so return it as is
-			if (count($elements) == 1)
+			if ($fp = fopen($cachedir . DS . $cachefile, 'wb')) 
 			{
-				return $thispath . DS . $elements[0] . '.css';
+				fwrite($fp, $contents);
+				fclose($fp);
 			}
-
-			// Try the cache first to see if the combined files were already generated
-			$cachefile = 'system-' . $hash . '.css';
-
-			if (!file_exists($cachedir . DS . $cachefile)) 
-			{
-				$contents = '';
-				reset($elements);
-
-				foreach ($elements as $k => $element) 
-				{
-					$contents .= "\n\n" . file_get_contents($thispath . DS . $element . '.css');
-				}
-				$patterns = array(
-					'!/\*[^*]*\*+([^/][^*]*\*+)*/!',  /* remove comments */
-					'/[\n\r \t]/',                    /* remove tabs, spaces, newlines, etc. */
-					'/ +/'                           /* collapse multiple spaces to a single space */
-					/* '/ ?([,:;{}]) ?/'                 remove space before and after , : ; { }     [!] apparently, IE 7 doesn't like this and won't process the stylesheet */
-				);
-				$replacements = array(
-					'',
-					' ',
-					' '/*,
-					'$1'*/
-				);
-				$contents = preg_replace($patterns, $replacements, $contents);
-				$contents = str_replace("url('/media/system/", "url('" . rtrim(JURI::getInstance()->base(true), DS) . "/media/system/", $contents);
-
-				if ($fp = fopen($cachedir . DS . $cachefile, 'wb')) 
-				{
-					fwrite($fp, $contents);
-					fclose($fp);
-				}
-			}
-
-			$output = rtrim(JURI::getInstance()->base(true), DS) . DS . 'cache' . DS . $cachefile;
 		}
 
-		return $output;
+		return DS . 'cache' . DS . $cachefile;
 	}
 }
