@@ -32,21 +32,17 @@
 defined('_JEXEC') or die( 'Restricted access' );
 ?>
 <p class="answer">
-	<?php if ($this->resource->alias) : ?>
-		<a href="<?php echo JRoute::_('index.php?option=com_resources&alias=' . $this->resource->alias . '&active=questions'); ?>">
-	<?php else : ?>
-		<a href="<?php echo JRoute::_('index.php?option=com_resources&id=' . $this->resource->id . '&active=questions'); ?>">
-	<?php endif; ?>
+	<a href="<?php echo JRoute::_('index.php?option=com_resources&alias='.$this->resource->alias.'&active=questions'); ?>">
 		<?php
-			if ($this->count == 1)
+			if ($this->count == 1) 
 			{
-				echo JText::sprintf('PLG_RESOURCES_QUESTIONS_NUM_QUESTION', $this->count);
-			}
-			else
+				 echo JText::sprintf('PLG_RESOURCES_QUESTIONS_NUM_QUESTION', $this->count);
+			} 
+			else 
 			{
 				echo JText::sprintf('PLG_RESOURCES_QUESTIONS_NUM_QUESTIONS', $this->count);
 			}
 		?>
 	</a>
-		(<a href="<?php echo JRoute::_('index.php?option=com_resources&id=' . $this->resource->id . '&active=questions&action=new'); ?>"><?php echo JText::_('PLG_RESOURCES_QUESTIONS_ASK_A_QUESTION'); ?></a>)
-</p>
+	(<a href="/answers/question/new/?tag=tool:<?php echo $this->resource->alias; ?>"><?php echo JText::_('PLG_RESOURCES_QUESTIONS_ASK_A_QUESTION'); ?></a>)
+</p>
\ No newline at end of file
