@@ -31,21 +31,30 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die('Restricted access');
 
+jimport('joomla.plugin.plugin');
+
 /**
  * Resources Plugin class for related resources
  */
-class plgResourcesRelated extends \Hubzero\Plugin\Plugin
+class plgResourcesRelated extends JPlugin
 {
 	/**
-	 * Affects constructor behavior. If true, language files will be loaded automatically.
-	 *
-	 * @var    boolean
+	 * Constructor
+	 * 
+	 * @param      object &$subject Event observer
+	 * @param      array  $config   Optional config values
+	 * @return     void
 	 */
-	protected $_autoloadLanguage = true;
+	public function __construct(&$subject, $config)
+	{
+		parent::__construct($subject, $config);
+
+		$this->loadLanguage();
+	}
 
 	/**
 	 * Return the alias and name for this category of content
-	 *
+	 * 
 	 * @param      object $resource Current resource
 	 * @return     array
 	 */
@@ -59,7 +68,7 @@ class plgResourcesRelated extends \Hubzero\Plugin\Plugin
 
 	/**
 	 * Return data on a resource sub view (this will be some form of HTML)
-	 *
+	 * 
 	 * @param      object  $resource Current resource
 	 * @param      string  $option    Name of the component
 	 * @param      integer $miniview  View style
@@ -68,34 +77,33 @@ class plgResourcesRelated extends \Hubzero\Plugin\Plugin
 	public function onResourcesSub($resource, $option, $miniview=0)
 	{
 		$arr = array(
-			'area'     => $this->_name,
-			'html'     => '',
+			'area' => 'related',
+			'html' => '',
 			'metadata' => ''
 		);
 
-		$database = JFactory::getDBO();
+		$database =& JFactory::getDBO();
 
 		// Build the query that checks topic pages
-		$sql1 = "SELECT v.id, v.pageid, MAX(v.version) AS version, w.title, w.pagename AS alias, v.pagetext AS introtext,
-					NULL AS type, NULL AS published, NULL AS publish_up, w.scope, w.rating, w.times_rated, w.ranking, 'Topic' AS section, w.`group_cn`
-				FROM `#__wiki_page` AS w
-				JOIN `#__wiki_version` AS v ON w.id=v.pageid
-				JOIN `#__wiki_page_links` AS wl ON wl.page_id=w.id
-				WHERE v.approved=1 AND wl.scope='resource' AND wl.scope_id=" . $database->Quote($resource->id);
-
-		$juser = JFactory::getUser();
-		if (!$juser->get('guest'))
+		$sql1 = "SELECT v.id, v.pageid, MAX(v.version) AS version, w.title, w.pagename AS alias, v.pagetext AS introtext, NULL AS type, NULL AS published, NULL AS publish_up, w.scope, w.rating, w.times_rated, w.ranking, 'Topic' AS section, w.`group_cn`  
+				FROM #__wiki_page AS w, #__wiki_version AS v
+				WHERE w.id=v.pageid AND v.approved=1 AND (v.pagetext LIKE '%[[Resource(".$resource->id . ")]]%' OR v.pagetext LIKE '%[[Resource(" . $resource->id . ",%' OR v.pagetext LIKE '%[/resources/" . $resource->id . " %'";
+		$sql1 .= ($resource->alias) ? " OR v.pagetext LIKE '%[[Resource(" . $resource->alias . "%') " : ") ";
+		$juser =& JFactory::getUser();
+		if (!$juser->get('guest')) 
 		{
-			if ($juser->authorize('com_resources', 'manage')
-			 || $juser->authorize('com_groups', 'manage'))
+			if ($juser->authorize('com_resources', 'manage') 
+			 || $juser->authorize('com_groups', 'manage')) 
 			{
 				$sql1 .= '';
-			}
-			else
+			} 
+			else 
 			{
-				$ugs = \Hubzero\User\Helper::getGroups($juser->get('id'), 'members');
+				ximport('Hubzero_User_Helper');
+
+				$ugs = Hubzero_User_Helper::getGroups($juser->get('id'), 'members');
 				$groups = array();
-				if ($ugs && count($ugs) > 0)
+				if ($ugs && count($ugs) > 0) 
 				{
 					foreach ($ugs as $ug)
 					{
@@ -106,8 +114,8 @@ class plgResourcesRelated extends \Hubzero\Plugin\Plugin
 
 				$sql1 .= "AND (w.access!=1 OR (w.access=1 AND (w.group_cn IN ($g) OR w.created_by='" . $juser->get('id') . "'))) ";
 			}
-		}
-		else
+		} 
+		else 
 		{
 			$sql1 .= "AND w.access!=1 ";
 		}
@@ -115,27 +123,28 @@ class plgResourcesRelated extends \Hubzero\Plugin\Plugin
 
 		// Build the query that checks resource parents
 		$sql2 = "SELECT DISTINCT r.id, NULL AS pageid, NULL AS version, r.title, r.alias, r.introtext, r.type, r.published, r.publish_up, "
-			 . " NULL AS scope, r.rating, r.times_rated, r.ranking, rt.type AS section, NULL AS `group` "
-			 . " FROM #__resource_types AS rt, #__resources AS r"
-			 . " JOIN #__resource_assoc AS a ON r.id=a.parent_id"
-			 . " LEFT JOIN #__resource_types AS t ON r.logical_type=t.id"
-			 . " WHERE r.published=1 AND a.child_id=" . $resource->id . " AND r.type=rt.id AND r.type!=8 ";
-		if (!$juser->get('guest'))
+			 . "\n NULL AS scope, r.rating, r.times_rated, r.ranking, rt.type AS section, NULL AS `group` "
+			 . "\n FROM #__resource_types AS rt, #__resources AS r"
+			 . "\n JOIN #__resource_assoc AS a ON r.id=a.parent_id"
+			 . "\n LEFT JOIN #__resource_types AS t ON r.logical_type=t.id"
+			 . "\n WHERE r.published=1 AND a.child_id=" . $resource->id . " AND r.type=rt.id AND r.type!=8 ";
+		if (!$juser->get('guest')) 
 		{
-			if ($juser->authorize('com_resources', 'manage')
-			 || $juser->authorize('com_groups', 'manage'))
+			if ($juser->authorize('com_resources', 'manage') 
+			 || $juser->authorize('com_groups', 'manage')) 
 			{
 				$sql2 .= '';
-			}
-			else
+			} 
+			else 
 			{
 				$sql2 .= "AND (r.access!=1 OR (r.access=1 AND (r.group_owner IN ($g) OR r.created_by='" . $juser->get('id') . "'))) ";
 			}
-		}
-		else
+		} 
+		else 
 		{
 			$sql2 .= "AND r.access=0 ";
 		}
+		//echo '<!-- '.$sql2.' -->';
 		$sql2 .= "ORDER BY r.ranking LIMIT 10";
 
 		// Build the final query
@@ -143,24 +152,39 @@ class plgResourcesRelated extends \Hubzero\Plugin\Plugin
 
 		// Execute the query
 		$database->setQuery($query);
+		$related = $database->loadObjectList();
 
-		$view = new \Hubzero\Plugin\View(array(
-			'folder'  => $this->_type,
-			'element' => $this->_name,
-			'name'    => 'browse'
-		));
+		ximport('Hubzero_View_Helper_Html');
 
 		// Instantiate a view
-		if ($miniview)
+		ximport('Hubzero_Plugin_View');
+		if ($miniview) 
 		{
-			$view->setLayout('mini');
+			$view = new Hubzero_Plugin_View(
+				array(
+					'folder'  => 'resources',
+					'element' => 'related',
+					'name'    => 'browse',
+					'layout'  => 'mini'
+				)
+			);
+		} 
+		else 
+		{
+			$view = new Hubzero_Plugin_View(
+				array(
+					'folder'  => 'resources',
+					'element' => 'related',
+					'name'    => 'browse'
+				)
+			);
 		}
 
 		// Pass the view some info
 		$view->option   = $option;
 		$view->resource = $resource;
-		$view->related  = $database->loadObjectList();
-		if ($this->getError())
+		$view->related  = $related;
+		if ($this->getError()) 
 		{
 			foreach ($this->getErrors() as $error)
 			{
